Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type AlertmanagerExpansion
- type AlertmanagerInterface
- type AlertmanagersGetter
- type MonitoringV1Client
- func (c *MonitoringV1Client) Alertmanagers(namespace string) AlertmanagerInterface
- func (c *MonitoringV1Client) PodMonitors(namespace string) PodMonitorInterface
- func (c *MonitoringV1Client) Probes(namespace string) ProbeInterface
- func (c *MonitoringV1Client) PrometheusRules(namespace string) PrometheusRuleInterface
- func (c *MonitoringV1Client) Prometheuses(namespace string) PrometheusInterface
- func (c *MonitoringV1Client) RESTClient() rest.Interface
- func (c *MonitoringV1Client) ServiceMonitors(namespace string) ServiceMonitorInterface
- func (c *MonitoringV1Client) ThanosRulers(namespace string) ThanosRulerInterface
- type MonitoringV1Interface
- type PodMonitorExpansion
- type PodMonitorInterface
- type PodMonitorsGetter
- type ProbeExpansion
- type ProbeInterface
- type ProbesGetter
- type PrometheusExpansion
- type PrometheusInterface
- type PrometheusRuleExpansion
- type PrometheusRuleInterface
- type PrometheusRulesGetter
- type PrometheusesGetter
- type ServiceMonitorExpansion
- type ServiceMonitorInterface
- type ServiceMonitorsGetter
- type ThanosRulerExpansion
- type ThanosRulerInterface
- type ThanosRulersGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlertmanagerExpansion ¶
type AlertmanagerExpansion interface{}
type AlertmanagerInterface ¶
type AlertmanagerInterface interface {
Create(ctx context.Context, alertmanager *monitoringv1.Alertmanager, opts metav1.CreateOptions) (*monitoringv1.Alertmanager, error)
Update(ctx context.Context, alertmanager *monitoringv1.Alertmanager, opts metav1.UpdateOptions) (*monitoringv1.Alertmanager, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, alertmanager *monitoringv1.Alertmanager, opts metav1.UpdateOptions) (*monitoringv1.Alertmanager, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.Alertmanager, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.AlertmanagerList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.Alertmanager, err error)
Apply(ctx context.Context, alertmanager *applyconfigurationmonitoringv1.AlertmanagerApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Alertmanager, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, alertmanager *applyconfigurationmonitoringv1.AlertmanagerApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Alertmanager, err error)
GetScale(ctx context.Context, alertmanagerName string, options metav1.GetOptions) (*autoscalingv1.Scale, error)
UpdateScale(ctx context.Context, alertmanagerName string, scale *autoscalingv1.Scale, opts metav1.UpdateOptions) (*autoscalingv1.Scale, error)
AlertmanagerExpansion
}
AlertmanagerInterface has methods to work with Alertmanager resources.
type AlertmanagersGetter ¶
type AlertmanagersGetter interface {
Alertmanagers(namespace string) AlertmanagerInterface
}
AlertmanagersGetter has a method to return a AlertmanagerInterface. A group's client should implement this interface.
type MonitoringV1Client ¶
type MonitoringV1Client struct {
// contains filtered or unexported fields
}
MonitoringV1Client is used to interact with features provided by the monitoring.coreos.com group.
func New ¶
func New(c rest.Interface) *MonitoringV1Client
New creates a new MonitoringV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*MonitoringV1Client, error)
NewForConfig creates a new MonitoringV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶ added in v0.55.0
NewForConfigAndClient creates a new MonitoringV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *MonitoringV1Client
NewForConfigOrDie creates a new MonitoringV1Client for the given config and panics if there is an error in the config.
func (*MonitoringV1Client) Alertmanagers ¶
func (c *MonitoringV1Client) Alertmanagers(namespace string) AlertmanagerInterface
func (*MonitoringV1Client) PodMonitors ¶
func (c *MonitoringV1Client) PodMonitors(namespace string) PodMonitorInterface
func (*MonitoringV1Client) Probes ¶
func (c *MonitoringV1Client) Probes(namespace string) ProbeInterface
func (*MonitoringV1Client) PrometheusRules ¶
func (c *MonitoringV1Client) PrometheusRules(namespace string) PrometheusRuleInterface
func (*MonitoringV1Client) Prometheuses ¶
func (c *MonitoringV1Client) Prometheuses(namespace string) PrometheusInterface
func (*MonitoringV1Client) RESTClient ¶
func (c *MonitoringV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*MonitoringV1Client) ServiceMonitors ¶
func (c *MonitoringV1Client) ServiceMonitors(namespace string) ServiceMonitorInterface
func (*MonitoringV1Client) ThanosRulers ¶
func (c *MonitoringV1Client) ThanosRulers(namespace string) ThanosRulerInterface
type MonitoringV1Interface ¶
type MonitoringV1Interface interface {
RESTClient() rest.Interface
AlertmanagersGetter
PodMonitorsGetter
ProbesGetter
PrometheusesGetter
PrometheusRulesGetter
ServiceMonitorsGetter
ThanosRulersGetter
}
type PodMonitorExpansion ¶
type PodMonitorExpansion interface{}
type PodMonitorInterface ¶
type PodMonitorInterface interface {
Create(ctx context.Context, podMonitor *monitoringv1.PodMonitor, opts metav1.CreateOptions) (*monitoringv1.PodMonitor, error)
Update(ctx context.Context, podMonitor *monitoringv1.PodMonitor, opts metav1.UpdateOptions) (*monitoringv1.PodMonitor, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, podMonitor *monitoringv1.PodMonitor, opts metav1.UpdateOptions) (*monitoringv1.PodMonitor, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.PodMonitor, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.PodMonitorList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.PodMonitor, err error)
Apply(ctx context.Context, podMonitor *applyconfigurationmonitoringv1.PodMonitorApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.PodMonitor, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, podMonitor *applyconfigurationmonitoringv1.PodMonitorApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.PodMonitor, err error)
PodMonitorExpansion
}
PodMonitorInterface has methods to work with PodMonitor resources.
type PodMonitorsGetter ¶
type PodMonitorsGetter interface {
PodMonitors(namespace string) PodMonitorInterface
}
PodMonitorsGetter has a method to return a PodMonitorInterface. A group's client should implement this interface.
type ProbeExpansion ¶
type ProbeExpansion interface{}
type ProbeInterface ¶
type ProbeInterface interface {
Create(ctx context.Context, probe *monitoringv1.Probe, opts metav1.CreateOptions) (*monitoringv1.Probe, error)
Update(ctx context.Context, probe *monitoringv1.Probe, opts metav1.UpdateOptions) (*monitoringv1.Probe, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, probe *monitoringv1.Probe, opts metav1.UpdateOptions) (*monitoringv1.Probe, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.Probe, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.ProbeList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.Probe, err error)
Apply(ctx context.Context, probe *applyconfigurationmonitoringv1.ProbeApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Probe, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, probe *applyconfigurationmonitoringv1.ProbeApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Probe, err error)
ProbeExpansion
}
ProbeInterface has methods to work with Probe resources.
type ProbesGetter ¶
type ProbesGetter interface {
Probes(namespace string) ProbeInterface
}
ProbesGetter has a method to return a ProbeInterface. A group's client should implement this interface.
type PrometheusExpansion ¶
type PrometheusExpansion interface{}
type PrometheusInterface ¶
type PrometheusInterface interface {
Create(ctx context.Context, prometheus *monitoringv1.Prometheus, opts metav1.CreateOptions) (*monitoringv1.Prometheus, error)
Update(ctx context.Context, prometheus *monitoringv1.Prometheus, opts metav1.UpdateOptions) (*monitoringv1.Prometheus, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, prometheus *monitoringv1.Prometheus, opts metav1.UpdateOptions) (*monitoringv1.Prometheus, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.Prometheus, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.PrometheusList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.Prometheus, err error)
Apply(ctx context.Context, prometheus *applyconfigurationmonitoringv1.PrometheusApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Prometheus, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, prometheus *applyconfigurationmonitoringv1.PrometheusApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.Prometheus, err error)
GetScale(ctx context.Context, prometheusName string, options metav1.GetOptions) (*autoscalingv1.Scale, error)
UpdateScale(ctx context.Context, prometheusName string, scale *autoscalingv1.Scale, opts metav1.UpdateOptions) (*autoscalingv1.Scale, error)
PrometheusExpansion
}
PrometheusInterface has methods to work with Prometheus resources.
type PrometheusRuleExpansion ¶
type PrometheusRuleExpansion interface{}
type PrometheusRuleInterface ¶
type PrometheusRuleInterface interface {
Create(ctx context.Context, prometheusRule *monitoringv1.PrometheusRule, opts metav1.CreateOptions) (*monitoringv1.PrometheusRule, error)
Update(ctx context.Context, prometheusRule *monitoringv1.PrometheusRule, opts metav1.UpdateOptions) (*monitoringv1.PrometheusRule, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, prometheusRule *monitoringv1.PrometheusRule, opts metav1.UpdateOptions) (*monitoringv1.PrometheusRule, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.PrometheusRule, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.PrometheusRuleList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.PrometheusRule, err error)
Apply(ctx context.Context, prometheusRule *applyconfigurationmonitoringv1.PrometheusRuleApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.PrometheusRule, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, prometheusRule *applyconfigurationmonitoringv1.PrometheusRuleApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.PrometheusRule, err error)
PrometheusRuleExpansion
}
PrometheusRuleInterface has methods to work with PrometheusRule resources.
type PrometheusRulesGetter ¶
type PrometheusRulesGetter interface {
PrometheusRules(namespace string) PrometheusRuleInterface
}
PrometheusRulesGetter has a method to return a PrometheusRuleInterface. A group's client should implement this interface.
type PrometheusesGetter ¶
type PrometheusesGetter interface {
Prometheuses(namespace string) PrometheusInterface
}
PrometheusesGetter has a method to return a PrometheusInterface. A group's client should implement this interface.
type ServiceMonitorExpansion ¶
type ServiceMonitorExpansion interface{}
type ServiceMonitorInterface ¶
type ServiceMonitorInterface interface {
Create(ctx context.Context, serviceMonitor *monitoringv1.ServiceMonitor, opts metav1.CreateOptions) (*monitoringv1.ServiceMonitor, error)
Update(ctx context.Context, serviceMonitor *monitoringv1.ServiceMonitor, opts metav1.UpdateOptions) (*monitoringv1.ServiceMonitor, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, serviceMonitor *monitoringv1.ServiceMonitor, opts metav1.UpdateOptions) (*monitoringv1.ServiceMonitor, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.ServiceMonitor, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.ServiceMonitorList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.ServiceMonitor, err error)
Apply(ctx context.Context, serviceMonitor *applyconfigurationmonitoringv1.ServiceMonitorApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.ServiceMonitor, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, serviceMonitor *applyconfigurationmonitoringv1.ServiceMonitorApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.ServiceMonitor, err error)
ServiceMonitorExpansion
}
ServiceMonitorInterface has methods to work with ServiceMonitor resources.
type ServiceMonitorsGetter ¶
type ServiceMonitorsGetter interface {
ServiceMonitors(namespace string) ServiceMonitorInterface
}
ServiceMonitorsGetter has a method to return a ServiceMonitorInterface. A group's client should implement this interface.
type ThanosRulerExpansion ¶
type ThanosRulerExpansion interface{}
type ThanosRulerInterface ¶
type ThanosRulerInterface interface {
Create(ctx context.Context, thanosRuler *monitoringv1.ThanosRuler, opts metav1.CreateOptions) (*monitoringv1.ThanosRuler, error)
Update(ctx context.Context, thanosRuler *monitoringv1.ThanosRuler, opts metav1.UpdateOptions) (*monitoringv1.ThanosRuler, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, thanosRuler *monitoringv1.ThanosRuler, opts metav1.UpdateOptions) (*monitoringv1.ThanosRuler, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*monitoringv1.ThanosRuler, error)
List(ctx context.Context, opts metav1.ListOptions) (*monitoringv1.ThanosRulerList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *monitoringv1.ThanosRuler, err error)
Apply(ctx context.Context, thanosRuler *applyconfigurationmonitoringv1.ThanosRulerApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.ThanosRuler, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, thanosRuler *applyconfigurationmonitoringv1.ThanosRulerApplyConfiguration, opts metav1.ApplyOptions) (result *monitoringv1.ThanosRuler, err error)
ThanosRulerExpansion
}
ThanosRulerInterface has methods to work with ThanosRuler resources.
type ThanosRulersGetter ¶
type ThanosRulersGetter interface {
ThanosRulers(namespace string) ThanosRulerInterface
}
ThanosRulersGetter has a method to return a ThanosRulerInterface. A group's client should implement this interface.